//+------------------------------------------------------------------+
//|                                                       Prim44.mq5 |
//|                        Copyright 2010, MetaQuotes Software Corp. |
//|                                              http://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2010, MetaQuotes Software Corp."
#property link      "http://www.mql5.com"
#property version   "1.00"
//+------------------------------------------------------------------+
//| Include                                                          |
//+------------------------------------------------------------------+
#include <Expert\Expert.mqh>
//--- available signals
#include <Expert\Signal\SignalAC.mqh>
#include <Expert\Signal\SignalEnvelopes.mqh>
//--- available trailing
#include <Expert\Trailing\TrailingFixedPips.mqh>
//--- available money management
#include <Expert\Money\MoneyNone.mqh>
//+------------------------------------------------------------------+
//| Inputs                                                           |
//+------------------------------------------------------------------+
//--- inputs for expert
input string             Expert_Title                  ="Prim44";   // Document name
ulong                    Expert_MagicNumber            =7963;       // 
bool                     Expert_EveryTick              =false;      // 
//--- inputs for main signal
input int                Signal_ThresholdOpen          =10;         // Signal threshold value to open [0...100]
input int                Signal_ThresholdClose         =20;         // Signal threshold value to close [0...100]
input double             Signal_PriceLevel             =0.0;        // Price level to execute a deal
input double             Signal_StopLevel              =500.0;       // Stop Loss level (in points)
input double             Signal_TakeLevel              =100.0;       // Take Profit level (in points)
input int                Signal_Expiration             =0;          // Expiration of pending orders (in bars)
input double             Signal_0_AC_Weight            =0.3;        // Accelerator Oscillator W1 Weight [0...1.0]
input double             Signal_1_AC_Weight            =0.3;        // Accelerator Oscillator D1 Weight [0...1.0]
input int                Signal_0_Envelopes_PeriodMA   =21;         // Envelopes(21,0,MODE_EMA,...) D1 Period of averaging
input double             Signal_0_Envelopes_Deviation  =3.0;        // Envelopes(21,0,MODE_EMA,...) D1 Deviation
input double             Signal_0_Envelopes_Weight     =0.3;        // Envelopes(21,0,MODE_EMA,...) D1 Weight [0...1.0]
input double             Signal_2_AC_Weight            =0.3;        // Accelerator Oscillator Weight [0...1.0]
input int                Signal_1_Envelopes_PeriodMA   =55;         // Envelopes(55,0,MODE_EMA,...) Period of averaging
input double             Signal_1_Envelopes_Deviation  =1.0;        // Envelopes(55,0,MODE_EMA,...) Deviation
input double             Signal_1_Envelopes_Weight     =0.3;        // Envelopes(55,0,MODE_EMA,...) Weight [0...1.0]
//--- inputs for trailing
input int                Trailing_FixedPips_StopLevel=250;        // Stop Loss trailing level (in points)
//+------------------------------------------------------------------+
//| Global expert object                                             |
//+------------------------------------------------------------------+
CExpert ExtExpert;
//+------------------------------------------------------------------+
//| Initialization function of the expert                            |
//+------------------------------------------------------------------+
int OnInit()
  {
//--- Initializing expert
   if(!ExtExpert.Init(Symbol(),Period(),Expert_EveryTick,Expert_MagicNumber))
     {
      //--- failed
      printf(__FUNCTION__+": error initializing expert");
      ExtExpert.Deinit();
      return(-1);
     }
//--- Creating signal
   CExpertSignal *signal=new CExpertSignal;
   if(signal==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating signal");
      ExtExpert.Deinit();
      return(-2);
     }
//---
   ExtExpert.InitSignal(signal);
   signal.ThresholdOpen(Signal_ThresholdOpen);
   signal.ThresholdClose(Signal_ThresholdClose);
   signal.PriceLevel(Signal_PriceLevel);
   signal.StopLevel(Signal_StopLevel);
   signal.TakeLevel(Signal_TakeLevel);
   signal.Expiration(Signal_Expiration);
//--- Creating filter CSignalAC
   CSignalAC *filter0=new CSignalAC;
   if(filter0==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating filter0");
      ExtExpert.Deinit();
      return(-3);
     }
   signal.AddFilter(filter0);
//--- Set filter parameters
   filter0.Period(PERIOD_W1);
   filter0.Weight(Signal_0_AC_Weight);
//--- Creating filter CSignalAC
   CSignalAC *filter1=new CSignalAC;
   if(filter1==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating filter1");
      ExtExpert.Deinit();
      return(-4);
     }
   signal.AddFilter(filter1);
//--- Set filter parameters
   filter1.Period(PERIOD_D1);
   filter1.Weight(Signal_1_AC_Weight);
//--- Creating filter CSignalEnvelopes
   CSignalEnvelopes *filter2=new CSignalEnvelopes;
   if(filter2==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating filter2");
      ExtExpert.Deinit();
      return(-5);
     }
   signal.AddFilter(filter2);
//--- Set filter parameters
   filter2.Period(PERIOD_D1);
   filter2.PeriodMA(Signal_0_Envelopes_PeriodMA);
   filter2.Method(MODE_EMA);
   filter2.Applied(PRICE_OPEN);
   filter2.Deviation(Signal_0_Envelopes_Deviation);
   filter2.Weight(Signal_0_Envelopes_Weight);
//--- Creating filter CSignalAC
   CSignalAC *filter3=new CSignalAC;
   if(filter3==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating filter3");
      ExtExpert.Deinit();
      return(-6);
     }
   signal.AddFilter(filter3);
//--- Set filter parameters
   filter3.Weight(Signal_2_AC_Weight);
//--- Creating filter CSignalEnvelopes
   CSignalEnvelopes *filter4=new CSignalEnvelopes;
   if(filter4==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating filter4");
      ExtExpert.Deinit();
      return(-7);
     }
   signal.AddFilter(filter4);
//--- Set filter parameters
   filter4.PeriodMA(Signal_1_Envelopes_PeriodMA);
   filter4.Method(MODE_EMA);
   filter4.Applied(PRICE_OPEN);
   filter4.Deviation(Signal_1_Envelopes_Deviation);
   filter4.Weight(Signal_1_Envelopes_Weight);
//--- Creation of trailing object
   CTrailingFixedPips *trailing=new CTrailingFixedPips;
   if(trailing==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating trailing");
      ExtExpert.Deinit();
      return(-8);
     }
//--- Add trailing to expert (will be deleted automatically))
   if(!ExtExpert.InitTrailing(trailing))
     {
      //--- failed
      printf(__FUNCTION__+": error initializing trailing");
      ExtExpert.Deinit();
      return(-9);
     }
//--- Set trailing parameters
   trailing.StopLevel(Trailing_FixedPips_StopLevel);
   trailing.ProfitLevel(100);
//--- Creation of money object
   CMoneyNone *money=new CMoneyNone;
   if(money==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating money");
      ExtExpert.Deinit();
      return(-10);
     }
//--- Add money to expert (will be deleted automatically))
   if(!ExtExpert.InitMoney(money))
     {
      //--- failed
      printf(__FUNCTION__+": error initializing money");
      ExtExpert.Deinit();
      return(-11);
     }
//--- Set money parameters
//--- Check all trading objects parameters
   if(!ExtExpert.ValidationSettings())
     {
      //--- failed
      ExtExpert.Deinit();
      return(-12);
     }
//--- Tuning of all necessary indicators
   if(!ExtExpert.InitIndicators())
     {
      //--- failed
      printf(__FUNCTION__+": error initializing indicators");
      ExtExpert.Deinit();
      return(-13);
     }
//--- ok
   return(0);
  }
//+------------------------------------------------------------------+
//| Deinitialization function of the expert                          |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
  {
   ExtExpert.Deinit();
  }
//+------------------------------------------------------------------+
//| "Tick" event handler function                                    |
//+------------------------------------------------------------------+
void OnTick()
  {
   ExtExpert.OnTick();
  }
//+------------------------------------------------------------------+
//| "Trade" event handler function                                   |
//+------------------------------------------------------------------+
void OnTrade()
  {
   ExtExpert.OnTrade();
  }
//+------------------------------------------------------------------+
//| "Timer" event handler function                                   |
//+------------------------------------------------------------------+
void OnTimer()
  {
   ExtExpert.OnTimer();
  }
//+------------------------------------------------------------------+
